VSNProfile
==========

.. contents::

For a documentation of the variables, please look at the documentation of :class:`ProfileInterface <pyhafas.profile.interfaces.ProfileInterface>`

.. automodule:: pyhafas.profile.vsn
   :members:
   :undoc-members:
   :show-inheritance:
